@@ -1,11 +1,12 @@
 import warnings
-from typing import Optional, Dict, List, Union
+from typing import Dict, List, Optional, Union
 
 import bleach
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.mail import EmailMultiAlternatives
 from django.template.loader import render_to_string
+from django.utils import translation
 
 from snitch.settings import ENABLED_SEND_NOTIFICATIONS
 from snitch.tasks import send_email_asynchronously
@@ -19,7 +20,11 @@ class TemplateEmailMessage:
     default_template_name: str = ""
     default_subject: str = ""
     default_from_email: str = ""
+    default_reply_to: str = ""
+    default_bcc: str = ""
+    default_cc: str = ""
     fake: bool = False
+    use_i18n: bool = False
 
     def __init__(
         self,
@@ -29,6 +34,9 @@ class TemplateEmailMessage:
         from_email: Optional[str] = None,
         attaches: Optional[List] = None,
         template_name: Optional[str] = None,
+        reply_to: Optional[str] = None,
+        bcc: Optional[str] = None,
+        cc: Optional[str] = None,
     ):
         self.template_name = (
             self.default_template_name if template_name is None else template_name
@@ -41,9 +49,16 @@ class TemplateEmailMessage:
             self.to = to
         self.subject = "%s" % self.default_subject if subject is None else subject
         self.from_email = self.default_from_email if from_email is None else from_email
+        self.reply_to = self.default_reply_to if reply_to is None else reply_to
+        self.bcc = self.default_bcc if bcc is None else bcc
+        self.cc = self.default_bcc if cc is None else cc
         self.attaches = [] if attaches is None else attaches
         self.default_context = {} if context is None else context
 
+    def get_language(self) -> str:
+        """Gets the language for the email."""
+        return settings.LANGUAGE_CODE
+
     def get_context(self) -> Dict:
         """Hook to customize context."""
         # Add default context
@@ -73,8 +88,11 @@ class TemplateEmailMessage:
             email = EmailMultiAlternatives(
                 subject=self.subject,
                 body=message_txt,
+                bcc=self.bcc,
+                cc=self.cc,
                 from_email=self.from_email,
                 to=self.to,
+                reply_to=self.reply_to,
             )
             email.attach_alternative(message, "text/html")
             for attach in self.attaches:
@@ -88,6 +106,9 @@ class TemplateEmailMessage:
             return
 
         use_async = not self.attaches and use_async
+        if self.use_i18n and settings.USE_I18N:
+            language = self.get_language()
+            translation.activate(language)
         context = self.get_context()
         message = render_to_string(self.template_name, context, using="django")
         message_txt = message.replace("\n", "")
